/* topbar.c generated by valac 0.25.2.7-aa52, the Vala compiler
 * generated from topbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>
#include <gio/gio.h>


#define BOXES_TYPE_TOPBAR_PAGE (boxes_topbar_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_PROPERTIES_TOOLBAR (boxes_properties_toolbar_get_type ())
#define BOXES_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar))
#define BOXES_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))
#define BOXES_IS_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_IS_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_PROPERTIES_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))

typedef struct _BoxesPropertiesToolbar BoxesPropertiesToolbar;
typedef struct _BoxesPropertiesToolbarClass BoxesPropertiesToolbarClass;

#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;

#define BOXES_TYPE_COLLECTION_TOOLBAR (boxes_collection_toolbar_get_type ())
#define BOXES_COLLECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbar))
#define BOXES_COLLECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbarClass))
#define BOXES_IS_COLLECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_TOOLBAR))
#define BOXES_IS_COLLECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_TOOLBAR))
#define BOXES_COLLECTION_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbarClass))

typedef struct _BoxesCollectionToolbar BoxesCollectionToolbar;
typedef struct _BoxesCollectionToolbarClass BoxesCollectionToolbarClass;

#define BOXES_TYPE_SELECTION_TOOLBAR (boxes_selection_toolbar_get_type ())
#define BOXES_SELECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbar))
#define BOXES_SELECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbarClass))
#define BOXES_IS_SELECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTION_TOOLBAR))
#define BOXES_IS_SELECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTION_TOOLBAR))
#define BOXES_SELECTION_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbarClass))

typedef struct _BoxesSelectionToolbar BoxesSelectionToolbar;
typedef struct _BoxesSelectionToolbarClass BoxesSelectionToolbarClass;

#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesWizardToolbarPrivate BoxesWizardToolbarPrivate;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesDisplayPagePrivate BoxesDisplayPagePrivate;

typedef enum  {
	BOXES_TOPBAR_PAGE_COLLECTION,
	BOXES_TOPBAR_PAGE_SELECTION,
	BOXES_TOPBAR_PAGE_WIZARD,
	BOXES_TOPBAR_PAGE_PROPERTIES,
	BOXES_TOPBAR_PAGE_DISPLAY
} BoxesTopbarPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesTopbar {
	GtkStack parent_instance;
	BoxesTopbarPrivate * priv;
	BoxesPropertiesToolbar* props_toolbar;
	BoxesWizardToolbar* wizard_toolbar;
	gchar* _status;
};

struct _BoxesTopbarClass {
	GtkStackClass parent_class;
};

struct _BoxesTopbarPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	BoxesCollectionToolbar* collection_toolbar;
	BoxesSelectionToolbar* selection_toolbar;
	BoxesDisplayToolbar* display_toolbar;
	BoxesAppWindow* window;
	BoxesTopbarPage _page;
};

struct _BoxesWizardToolbar {
	GtkHeaderBar parent_instance;
	BoxesWizardToolbarPrivate * priv;
	GtkButton* cancel_btn;
	GtkButton* back_btn;
	GtkButton* continue_btn;
	GtkButton* create_btn;
};

struct _BoxesWizardToolbarClass {
	GtkHeaderBarClass parent_class;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSelectionbar* selectionbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesDisplayPage {
	GtkBox parent_instance;
	BoxesDisplayPagePrivate * priv;
	BoxesDisplayToolbar* toolbar;
};

struct _BoxesDisplayPageClass {
	GtkBoxClass parent_class;
};


static gpointer boxes_topbar_parent_class = NULL;
static BoxesUIIface* boxes_topbar_boxes_ui_parent_iface = NULL;

GType boxes_topbar_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_properties_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_collection_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_selection_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_TOPBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_TOPBAR, BoxesTopbarPrivate))
enum  {
	BOXES_TOPBAR_DUMMY_PROPERTY,
	BOXES_TOPBAR_PREVIOUS_UI_STATE,
	BOXES_TOPBAR_UI_STATE,
	BOXES_TOPBAR_STATUS,
	BOXES_TOPBAR_PAGE
};
void boxes_topbar_click_back_button (BoxesTopbar* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_collection_toolbar_click_back_button (BoxesCollectionToolbar* self);
void boxes_wizard_toolbar_click_back_button (BoxesWizardToolbar* self);
void boxes_topbar_click_forward_button (BoxesTopbar* self);
void boxes_wizard_toolbar_click_forward_button (BoxesWizardToolbar* self);
void boxes_topbar_click_cancel_button (BoxesTopbar* self);
gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self);
void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value);
void boxes_topbar_click_new_button (BoxesTopbar* self);
void boxes_collection_toolbar_click_new_button (BoxesCollectionToolbar* self);
void boxes_topbar_click_search_button (BoxesTopbar* self);
void boxes_collection_toolbar_click_search_button (BoxesCollectionToolbar* self);
void boxes_topbar_setup_ui (BoxesTopbar* self, BoxesAppWindow* window);
static void __lambda100_ (BoxesTopbar* self);
void boxes_topbar_set_page (BoxesTopbar* self, BoxesTopbarPage value);
static void ___lambda100__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
void boxes_collection_toolbar_setup_ui (BoxesCollectionToolbar* self, BoxesAppWindow* window);
void boxes_selection_toolbar_setup_ui (BoxesSelectionToolbar* self, BoxesAppWindow* window);
void boxes_display_toolbar_setup_ui (BoxesDisplayToolbar* self, BoxesAppWindow* window);
void boxes_properties_toolbar_setup_ui (BoxesPropertiesToolbar* self, BoxesAppWindow* window);
static void boxes_topbar_ui_state_changed (BoxesTopbar* self);
BoxesTopbar* boxes_topbar_new (void);
BoxesTopbar* boxes_topbar_construct (GType object_type);
const gchar* boxes_topbar_get_status (BoxesTopbar* self);
void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value);
BoxesTopbarPage boxes_topbar_get_page (BoxesTopbar* self);
static GObject * boxes_topbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_topbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_topbar_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_topbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_topbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const gchar* BOXES_TOPBAR_page_names[5] = {"collection", "selection", "wizard", "properties", "display"};

GType boxes_topbar_page_get_type (void) {
	static volatile gsize boxes_topbar_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_topbar_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_TOPBAR_PAGE_COLLECTION, "BOXES_TOPBAR_PAGE_COLLECTION", "collection"}, {BOXES_TOPBAR_PAGE_SELECTION, "BOXES_TOPBAR_PAGE_SELECTION", "selection"}, {BOXES_TOPBAR_PAGE_WIZARD, "BOXES_TOPBAR_PAGE_WIZARD", "wizard"}, {BOXES_TOPBAR_PAGE_PROPERTIES, "BOXES_TOPBAR_PAGE_PROPERTIES", "properties"}, {BOXES_TOPBAR_PAGE_DISPLAY, "BOXES_TOPBAR_PAGE_DISPLAY", "display"}, {0, NULL, NULL}};
		GType boxes_topbar_page_type_id;
		boxes_topbar_page_type_id = g_enum_register_static ("BoxesTopbarPage", values);
		g_once_init_leave (&boxes_topbar_page_type_id__volatile, boxes_topbar_page_type_id);
	}
	return boxes_topbar_page_type_id__volatile;
}


void boxes_topbar_click_back_button (BoxesTopbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 33 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 34 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->window;
#line 34 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 34 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 34 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	switch (_tmp2_) {
#line 34 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 382 "topbar.c"
		{
#line 36 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 386 "topbar.c"
		}
#line 34 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_CREDS:
#line 390 "topbar.c"
		{
			BoxesCollectionToolbar* _tmp3_ = NULL;
#line 38 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			_tmp3_ = self->priv->collection_toolbar;
#line 38 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			boxes_collection_toolbar_click_back_button (_tmp3_);
#line 39 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 399 "topbar.c"
		}
#line 34 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 403 "topbar.c"
		{
			BoxesWizardToolbar* _tmp4_ = NULL;
#line 41 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			_tmp4_ = self->wizard_toolbar;
#line 41 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			boxes_wizard_toolbar_click_back_button (_tmp4_);
#line 42 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 412 "topbar.c"
		}
		default:
#line 34 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 417 "topbar.c"
	}
}


void boxes_topbar_click_forward_button (BoxesTopbar* self) {
	BoxesWizardToolbar* _tmp0_ = NULL;
#line 47 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 48 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->wizard_toolbar;
#line 48 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_wizard_toolbar_click_forward_button (_tmp0_);
#line 430 "topbar.c"
}


void boxes_topbar_click_cancel_button (BoxesTopbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 52 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 53 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->window;
#line 53 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 53 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 53 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	switch (_tmp2_) {
#line 53 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 450 "topbar.c"
		{
			BoxesAppWindow* _tmp3_ = NULL;
			gboolean _tmp4_ = FALSE;
			gboolean _tmp5_ = FALSE;
#line 55 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			_tmp3_ = self->priv->window;
#line 55 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			_tmp4_ = boxes_app_window_get_selection_mode (_tmp3_);
#line 55 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			_tmp5_ = _tmp4_;
#line 55 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			if (_tmp5_) {
#line 463 "topbar.c"
				BoxesAppWindow* _tmp6_ = NULL;
#line 56 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
				_tmp6_ = self->priv->window;
#line 56 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
				boxes_app_window_set_selection_mode (_tmp6_, FALSE);
#line 469 "topbar.c"
			}
#line 57 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			return;
#line 473 "topbar.c"
		}
#line 53 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 477 "topbar.c"
		{
			BoxesWizardToolbar* _tmp7_ = NULL;
			GtkButton* _tmp8_ = NULL;
#line 59 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			_tmp7_ = self->wizard_toolbar;
#line 59 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			_tmp8_ = _tmp7_->cancel_btn;
#line 59 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			gtk_button_clicked (_tmp8_);
#line 60 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			return;
#line 489 "topbar.c"
		}
		default:
#line 53 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 494 "topbar.c"
	}
}


void boxes_topbar_click_new_button (BoxesTopbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 64 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 65 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->window;
#line 65 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 65 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 65 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	if (_tmp2_ == BOXES_UI_STATE_COLLECTION) {
#line 513 "topbar.c"
		BoxesCollectionToolbar* _tmp3_ = NULL;
#line 66 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		_tmp3_ = self->priv->collection_toolbar;
#line 66 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		boxes_collection_toolbar_click_new_button (_tmp3_);
#line 519 "topbar.c"
	}
}


void boxes_topbar_click_search_button (BoxesTopbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 69 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 70 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->window;
#line 70 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 70 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 70 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	if (_tmp2_ == BOXES_UI_STATE_COLLECTION) {
#line 538 "topbar.c"
		BoxesCollectionToolbar* _tmp3_ = NULL;
#line 71 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		_tmp3_ = self->priv->collection_toolbar;
#line 71 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		boxes_collection_toolbar_click_search_button (_tmp3_);
#line 544 "topbar.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 101 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 552 "topbar.c"
}


static void __lambda100_ (BoxesTopbar* self) {
	BoxesTopbarPage _tmp0_ = 0;
	BoxesAppWindow* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 105 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = self->priv->window;
#line 105 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = boxes_app_window_get_selection_mode (_tmp1_);
#line 105 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 105 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	if (_tmp3_) {
#line 106 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		_tmp0_ = BOXES_TOPBAR_PAGE_SELECTION;
#line 571 "topbar.c"
	} else {
#line 106 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_COLLECTION);
#line 106 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		_tmp0_ = BOXES_TOPBAR_PAGE_COLLECTION;
#line 577 "topbar.c"
	}
#line 105 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_set_page (self, _tmp0_);
#line 581 "topbar.c"
}


static void ___lambda100__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 103 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	__lambda100_ ((BoxesTopbar*) self);
#line 588 "topbar.c"
}


void boxes_topbar_setup_ui (BoxesTopbar* self, BoxesAppWindow* window) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesDisplayToolbar* toolbar = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesDisplayPage* _tmp4_ = NULL;
	BoxesDisplayToolbar* _tmp5_ = NULL;
	BoxesDisplayToolbar* _tmp6_ = NULL;
	BoxesDisplayToolbar* _tmp7_ = NULL;
	BoxesDisplayToolbar* _tmp8_ = NULL;
	BoxesCollectionToolbar* _tmp9_ = NULL;
	BoxesAppWindow* _tmp10_ = NULL;
	BoxesSelectionToolbar* _tmp11_ = NULL;
	BoxesAppWindow* _tmp12_ = NULL;
	BoxesDisplayToolbar* _tmp13_ = NULL;
	BoxesAppWindow* _tmp14_ = NULL;
	BoxesPropertiesToolbar* _tmp15_ = NULL;
	BoxesAppWindow* _tmp16_ = NULL;
#line 100 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 100 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (window != NULL);
#line 101 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = window;
#line 101 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 101 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->window);
#line 101 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self->priv->window = _tmp1_;
#line 103 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = window;
#line 103 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) _tmp2_, "notify::selection-mode", (GCallback) ___lambda100__g_object_notify, self, 0);
#line 109 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp3_ = window;
#line 109 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp4_ = _tmp3_->display_page;
#line 109 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_->toolbar;
#line 109 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 109 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	toolbar = _tmp6_;
#line 110 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp7_ = self->priv->display_toolbar;
#line 110 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_bind_property_with_closures ((GObject*) toolbar, "title", (GObject*) _tmp7_, "title", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 111 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp8_ = self->priv->display_toolbar;
#line 111 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_bind_property_with_closures ((GObject*) toolbar, "subtitle", (GObject*) _tmp8_, "subtitle", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 113 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp9_ = self->priv->collection_toolbar;
#line 113 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp10_ = window;
#line 113 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_collection_toolbar_setup_ui (_tmp9_, _tmp10_);
#line 114 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp11_ = self->priv->selection_toolbar;
#line 114 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp12_ = window;
#line 114 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_selection_toolbar_setup_ui (_tmp11_, _tmp12_);
#line 115 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp13_ = self->priv->display_toolbar;
#line 115 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp14_ = window;
#line 115 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_display_toolbar_setup_ui (_tmp13_, _tmp14_);
#line 116 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp15_ = self->props_toolbar;
#line 116 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp16_ = window;
#line 116 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_properties_toolbar_setup_ui (_tmp15_, _tmp16_);
#line 100 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (toolbar);
#line 671 "topbar.c"
}


static void boxes_topbar_ui_state_changed (BoxesTopbar* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 119 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 120 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 120 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = _tmp0_;
#line 120 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	switch (_tmp1_) {
#line 120 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 688 "topbar.c"
		{
#line 122 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_COLLECTION);
#line 123 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 694 "topbar.c"
		}
#line 120 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_CREDS:
#line 698 "topbar.c"
		{
#line 126 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_COLLECTION);
#line 127 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 704 "topbar.c"
		}
#line 120 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 708 "topbar.c"
		{
#line 130 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_DISPLAY);
#line 131 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 714 "topbar.c"
		}
#line 120 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 718 "topbar.c"
		{
#line 134 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_PROPERTIES);
#line 135 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 724 "topbar.c"
		}
#line 120 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 728 "topbar.c"
		{
#line 138 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			boxes_topbar_set_page (self, BOXES_TOPBAR_PAGE_WIZARD);
#line 139 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 734 "topbar.c"
		}
		default:
		{
#line 142 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
			break;
#line 740 "topbar.c"
		}
	}
}


BoxesTopbar* boxes_topbar_construct (GType object_type) {
	BoxesTopbar * self = NULL;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) g_object_new (object_type, NULL);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	return self;
#line 752 "topbar.c"
}


BoxesTopbar* boxes_topbar_new (void) {
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	return boxes_topbar_construct (BOXES_TYPE_TOPBAR);
#line 759 "topbar.c"
}


static BoxesUIState boxes_topbar_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesTopbar* self;
	BoxesUIState _tmp0_ = 0;
#line 16 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 16 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 16 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 16 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	return result;
#line 775 "topbar.c"
}


static void boxes_topbar_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesTopbar* self;
	BoxesUIState _tmp0_ = 0;
#line 16 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 16 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 16 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 16 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 790 "topbar.c"
}


static BoxesUIState boxes_topbar_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesTopbar* self;
	BoxesUIState _tmp0_ = 0;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->_ui_state;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	return result;
#line 806 "topbar.c"
}


static void boxes_topbar_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesTopbar* self;
	BoxesUIState _tmp0_ = 0;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self->priv->_ui_state = _tmp0_;
#line 17 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 821 "topbar.c"
}


const gchar* boxes_topbar_get_status (BoxesTopbar* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 76 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 76 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->_status;
#line 76 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 76 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	return result;
#line 836 "topbar.c"
}


void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	BoxesCollectionToolbar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	BoxesDisplayToolbar* _tmp7_ = NULL;
#line 77 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 78 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_free0 (self->_status);
#line 78 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self->_status = _tmp1_;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp3_ = self->_status;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp3_;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	if (_tmp2_ == NULL) {
#line 79 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		_tmp2_ = "";
#line 867 "topbar.c"
	}
#line 79 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp4_ = self->priv->collection_toolbar;
#line 79 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_title ((GtkHeaderBar*) _tmp4_, _tmp2_);
#line 80 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp6_ = self->_status;
#line 80 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp6_;
#line 80 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	if (_tmp5_ == NULL) {
#line 80 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		_tmp5_ = "";
#line 881 "topbar.c"
	}
#line 80 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp7_ = self->priv->display_toolbar;
#line 80 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_header_bar_set_title ((GtkHeaderBar*) _tmp7_, _tmp5_);
#line 77 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "status");
#line 889 "topbar.c"
}


BoxesTopbarPage boxes_topbar_get_page (BoxesTopbar* self) {
	BoxesTopbarPage result;
	BoxesTopbarPage _tmp0_ = 0;
#line 86 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 86 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->_page;
#line 86 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	result = _tmp0_;
#line 86 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	return result;
#line 904 "topbar.c"
}


void boxes_topbar_set_page (BoxesTopbar* self, BoxesTopbarPage value) {
	BoxesTopbarPage _tmp0_ = 0;
	BoxesTopbarPage _tmp1_ = 0;
	const gchar* _tmp2_ = NULL;
#line 87 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 88 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = value;
#line 88 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self->priv->_page = _tmp0_;
#line 90 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = value;
#line 90 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = BOXES_TOPBAR_page_names[_tmp1_];
#line 90 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp2_);
#line 87 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_notify ((GObject *) self, "page");
#line 926 "topbar.c"
}


static void _boxes_topbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 95 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_ui_state_changed ((BoxesTopbar*) self);
#line 933 "topbar.c"
}


static GObject * boxes_topbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesTopbar * self;
#line 94 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_topbar_parent_class);
#line 94 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 94 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 95 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_topbar_ui_state_changed_g_object_notify, self, 0);
#line 97 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_CROSSFADE);
#line 94 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	return obj;
#line 953 "topbar.c"
}


static void boxes_topbar_class_init (BoxesTopbarClass * klass) {
	gint BoxesTopbar_private_offset;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesTopbarPrivate));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_topbar_get_property;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_topbar_set_property;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_topbar_constructor;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_topbar_finalize;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_STATUS, g_param_spec_string ("status", "status", "status", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_TOPBAR_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	BoxesTopbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/topbar.ui");
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props_toolbar", FALSE, G_STRUCT_OFFSET (BoxesTopbar, props_toolbar));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "collection_toolbar", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, collection_toolbar));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "selection_toolbar", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, selection_toolbar));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "display_toolbar", FALSE, BoxesTopbar_private_offset + G_STRUCT_OFFSET (BoxesTopbarPrivate, display_toolbar));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_toolbar", FALSE, G_STRUCT_OFFSET (BoxesTopbar, wizard_toolbar));
#line 993 "topbar.c"
}


static void boxes_topbar_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	iface->get_previous_ui_state = boxes_topbar_real_get_previous_ui_state;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	iface->set_previous_ui_state = boxes_topbar_real_set_previous_ui_state;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	iface->get_ui_state = boxes_topbar_real_get_ui_state;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	iface->set_ui_state = boxes_topbar_real_set_ui_state;
#line 1008 "topbar.c"
}


static void boxes_topbar_instance_init (BoxesTopbar * self) {
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self->priv = BOXES_TOPBAR_GET_PRIVATE (self);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_type_ensure (BOXES_TYPE_SELECTION_TOOLBAR);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_type_ensure (BOXES_TYPE_COLLECTION_TOOLBAR);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_TOOLBAR);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_type_ensure (BOXES_TYPE_PROPERTIES_TOOLBAR);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	g_type_ensure (BOXES_TYPE_DISPLAY_TOOLBAR);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1027 "topbar.c"
}


static void boxes_topbar_finalize (GObject* obj) {
	BoxesTopbar * self;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 19 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->props_toolbar);
#line 22 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->collection_toolbar);
#line 24 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->selection_toolbar);
#line 26 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->display_toolbar);
#line 28 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->wizard_toolbar);
#line 30 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->window);
#line 74 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	_g_free0 (self->_status);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (boxes_topbar_parent_class)->finalize (obj);
#line 1051 "topbar.c"
}


GType boxes_topbar_get_type (void) {
	static volatile gsize boxes_topbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_topbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesTopbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_topbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesTopbar), 0, (GInstanceInitFunc) boxes_topbar_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_topbar_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_topbar_type_id;
		boxes_topbar_type_id = g_type_register_static (gtk_stack_get_type (), "BoxesTopbar", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_topbar_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_topbar_type_id__volatile, boxes_topbar_type_id);
	}
	return boxes_topbar_type_id__volatile;
}


static void _vala_boxes_topbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesTopbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	switch (property_id) {
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PREVIOUS_UI_STATE:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_UI_STATE:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_STATUS:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		g_value_set_string (value, boxes_topbar_get_status (self));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PAGE:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		g_value_set_enum (value, boxes_topbar_get_page (self));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 1098 "topbar.c"
		default:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 1104 "topbar.c"
	}
}


static void _vala_boxes_topbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesTopbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
	switch (property_id) {
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PREVIOUS_UI_STATE:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_UI_STATE:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_STATUS:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		boxes_topbar_set_status (self, g_value_get_string (value));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_PAGE:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		boxes_topbar_set_page (self, g_value_get_enum (value));
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 1138 "topbar.c"
		default:
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/mclasen/Sources/gnome-boxes/src/topbar.vala"
		break;
#line 1144 "topbar.c"
	}
}



